Struct Infiniband
Source #[repr(C, packed(1))]
pub struct Infiniband {
pub header: DevicePathProtocol,
pub resource_flags: InfinibandResourceFlags,
pub port_gid: [u8; 16],
pub ioc_guid_or_service_id: u64,
pub target_port_id: u64,
pub device_id: u64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.