Struct Ipv4
Source #[repr(C, packed(1))]
pub struct Ipv4 {
pub header: DevicePathProtocol,
pub local_ip_address: [u8; 4],
pub remote_ip_address: [u8; 4],
pub local_port: u16,
pub remote_port: u16,
pub protocol: u16,
pub ip_address_origin: Ipv4AddressOrigin,
pub gateway_ip_address: [u8; 4],
pub subnet_mask: [u8; 4],
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.