Struct MacAddress
Source #[repr(C, packed(1))]
pub struct MacAddress {
pub header: DevicePathProtocol,
pub mac_address: [u8; 32],
pub interface_type: u8,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.