Struct RestService
Source #[repr(C, packed(1))]
pub struct RestService {
pub header: DevicePathProtocol,
pub service_type: RestServiceType,
pub access_mode: RestServiceAccessMode,
pub vendor_guid_and_data: [u8; 0],
}
vendor_guid_and_data: [u8; 0]
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.