Struct SasEx
Source #[repr(C, packed(1))]
pub struct SasEx {
pub header: DevicePathProtocol,
pub sas_address: [u8; 8],
pub logical_unit_number: [u8; 8],
pub info: u16,
pub relative_target_port: u16,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.