Struct Uart
Source #[repr(C, packed(1))]
pub struct Uart {
pub header: DevicePathProtocol,
pub _reserved: u32,
pub baud_rate: u64,
pub data_bits: u8,
pub parity: Parity,
pub stop_bits: StopBits,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.